@@ -157,7 +157,7 @@ class RedshiftDataAPIServiceClient(BaseClient):
         Sql: str,
         ClusterIdentifier: str = ...,
         DbUser: str = ...,
-        Parameters: Sequence["SqlParameterTypeDef"] = ...,
+        Parameters: Sequence[SqlParameterTypeDef] = ...,
         SecretArn: str = ...,
         StatementName: str = ...,
         WithEvent: bool = ...
