@@ -81,7 +81,7 @@ class DescribeTablePaginator(Boto3Paginator):
         Schema: str = ...,
         SecretArn: str = ...,
         Table: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeTableResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.DescribeTable.paginate)
@@ -96,7 +96,7 @@ class GetStatementResultPaginator(Boto3Paginator):
     """
 
     def paginate(
-        self, *, Id: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Id: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[GetStatementResultResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.GetStatementResult.paginate)
@@ -117,7 +117,7 @@ class ListDatabasesPaginator(Boto3Paginator):
         ClusterIdentifier: str = ...,
         DbUser: str = ...,
         SecretArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDatabasesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListDatabases.paginate)
@@ -140,7 +140,7 @@ class ListSchemasPaginator(Boto3Paginator):
         DbUser: str = ...,
         SchemaPattern: str = ...,
         SecretArn: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSchemasResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListSchemas.paginate)
@@ -160,7 +160,7 @@ class ListStatementsPaginator(Boto3Paginator):
         RoleLevel: bool = ...,
         StatementName: str = ...,
         Status: StatusStringType = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListStatementsResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListStatements.paginate)
@@ -184,7 +184,7 @@ class ListTablesPaginator(Boto3Paginator):
         SchemaPattern: str = ...,
         SecretArn: str = ...,
         TablePattern: str = ...,
-        PaginationConfig: "PaginatorConfigTypeDef" = ...
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListTablesResponseTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/redshift-data.html#RedshiftDataAPIService.Paginator.ListTables.paginate)
