@@ -25,39 +25,39 @@ else:
 
 __all__ = (
     "BatchExecuteStatementInputRequestTypeDef",
-    "BatchExecuteStatementOutputTypeDef",
+    "ResponseMetadataTypeDef",
     "CancelStatementRequestRequestTypeDef",
-    "CancelStatementResponseTypeDef",
     "ColumnMetadataTypeDef",
     "DescribeStatementRequestRequestTypeDef",
-    "DescribeStatementResponseTypeDef",
-    "DescribeTableRequestDescribeTablePaginateTypeDef",
+    "SqlParameterTypeDef",
+    "SubStatementDataTypeDef",
+    "PaginatorConfigTypeDef",
     "DescribeTableRequestRequestTypeDef",
+    "FieldTypeDef",
+    "GetStatementResultRequestRequestTypeDef",
+    "ListDatabasesRequestRequestTypeDef",
+    "ListSchemasRequestRequestTypeDef",
+    "ListStatementsRequestRequestTypeDef",
+    "ListTablesRequestRequestTypeDef",
+    "TableMemberTypeDef",
+    "BatchExecuteStatementOutputTypeDef",
+    "CancelStatementResponseTypeDef",
+    "ExecuteStatementOutputTypeDef",
+    "ListDatabasesResponseTypeDef",
+    "ListSchemasResponseTypeDef",
     "DescribeTableResponseTypeDef",
     "ExecuteStatementInputRequestTypeDef",
-    "ExecuteStatementOutputTypeDef",
-    "FieldTypeDef",
-    "GetStatementResultRequestGetStatementResultPaginateTypeDef",
-    "GetStatementResultRequestRequestTypeDef",
-    "GetStatementResultResponseTypeDef",
-    "ListDatabasesRequestListDatabasesPaginateTypeDef",
-    "ListDatabasesRequestRequestTypeDef",
-    "ListDatabasesResponseTypeDef",
-    "ListSchemasRequestListSchemasPaginateTypeDef",
-    "ListSchemasRequestRequestTypeDef",
-    "ListSchemasResponseTypeDef",
-    "ListStatementsRequestListStatementsPaginateTypeDef",
-    "ListStatementsRequestRequestTypeDef",
-    "ListStatementsResponseTypeDef",
-    "ListTablesRequestListTablesPaginateTypeDef",
-    "ListTablesRequestRequestTypeDef",
-    "ListTablesResponseTypeDef",
-    "PaginatorConfigTypeDef",
-    "ResponseMetadataTypeDef",
-    "SqlParameterTypeDef",
     "StatementDataTypeDef",
-    "SubStatementDataTypeDef",
-    "TableMemberTypeDef",
+    "DescribeStatementResponseTypeDef",
+    "DescribeTableRequestDescribeTablePaginateTypeDef",
+    "GetStatementResultRequestGetStatementResultPaginateTypeDef",
+    "ListDatabasesRequestListDatabasesPaginateTypeDef",
+    "ListSchemasRequestListSchemasPaginateTypeDef",
+    "ListStatementsRequestListStatementsPaginateTypeDef",
+    "ListTablesRequestListTablesPaginateTypeDef",
+    "GetStatementResultResponseTypeDef",
+    "ListTablesResponseTypeDef",
+    "ListStatementsResponseTypeDef",
 )
 
 _RequiredBatchExecuteStatementInputRequestTypeDef = TypedDict(
@@ -87,16 +87,14 @@ class BatchExecuteStatementInputRequestTypeDef(
     pass
 
 
-BatchExecuteStatementOutputTypeDef = TypedDict(
-    "BatchExecuteStatementOutputTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "ClusterIdentifier": str,
-        "CreatedAt": datetime,
-        "Database": str,
-        "DbUser": str,
-        "Id": str,
-        "SecretArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -107,14 +105,6 @@ CancelStatementRequestRequestTypeDef = TypedDict(
     },
 )
 
-CancelStatementResponseTypeDef = TypedDict(
-    "CancelStatementResponseTypeDef",
-    {
-        "Status": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ColumnMetadataTypeDef = TypedDict(
     "ColumnMetadataTypeDef",
     {
@@ -142,59 +132,52 @@ DescribeStatementRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeStatementResponseTypeDef = TypedDict(
-    "DescribeStatementResponseTypeDef",
+SqlParameterTypeDef = TypedDict(
+    "SqlParameterTypeDef",
     {
-        "ClusterIdentifier": str,
-        "CreatedAt": datetime,
-        "Database": str,
-        "DbUser": str,
-        "Duration": int,
-        "Error": str,
-        "HasResultSet": bool,
-        "Id": str,
-        "QueryParameters": List["SqlParameterTypeDef"],
-        "QueryString": str,
-        "RedshiftPid": int,
-        "RedshiftQueryId": int,
-        "ResultRows": int,
-        "ResultSize": int,
-        "SecretArn": str,
-        "Status": StatusStringType,
-        "SubStatements": List["SubStatementDataTypeDef"],
-        "UpdatedAt": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "name": str,
+        "value": str,
     },
 )
 
-_RequiredDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
-    "_RequiredDescribeTableRequestDescribeTablePaginateTypeDef",
+_RequiredSubStatementDataTypeDef = TypedDict(
+    "_RequiredSubStatementDataTypeDef",
     {
-        "Database": str,
+        "Id": str,
     },
 )
-_OptionalDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
-    "_OptionalDescribeTableRequestDescribeTablePaginateTypeDef",
+_OptionalSubStatementDataTypeDef = TypedDict(
+    "_OptionalSubStatementDataTypeDef",
     {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "Schema": str,
-        "SecretArn": str,
-        "Table": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "CreatedAt": datetime,
+        "Duration": int,
+        "Error": str,
+        "HasResultSet": bool,
+        "QueryString": str,
+        "RedshiftQueryId": int,
+        "ResultRows": int,
+        "ResultSize": int,
+        "Status": StatementStatusStringType,
+        "UpdatedAt": datetime,
     },
     total=False,
 )
 
 
-class DescribeTableRequestDescribeTablePaginateTypeDef(
-    _RequiredDescribeTableRequestDescribeTablePaginateTypeDef,
-    _OptionalDescribeTableRequestDescribeTablePaginateTypeDef,
-):
+class SubStatementDataTypeDef(_RequiredSubStatementDataTypeDef, _OptionalSubStatementDataTypeDef):
     pass
 
 
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
 _RequiredDescribeTableRequestRequestTypeDef = TypedDict(
     "_RequiredDescribeTableRequestRequestTypeDef",
     {
@@ -223,56 +206,6 @@ class DescribeTableRequestRequestTypeDef(
     pass
 
 
-DescribeTableResponseTypeDef = TypedDict(
-    "DescribeTableResponseTypeDef",
-    {
-        "ColumnList": List["ColumnMetadataTypeDef"],
-        "NextToken": str,
-        "TableName": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredExecuteStatementInputRequestTypeDef = TypedDict(
-    "_RequiredExecuteStatementInputRequestTypeDef",
-    {
-        "Database": str,
-        "Sql": str,
-    },
-)
-_OptionalExecuteStatementInputRequestTypeDef = TypedDict(
-    "_OptionalExecuteStatementInputRequestTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "DbUser": str,
-        "Parameters": Sequence["SqlParameterTypeDef"],
-        "SecretArn": str,
-        "StatementName": str,
-        "WithEvent": bool,
-    },
-    total=False,
-)
-
-
-class ExecuteStatementInputRequestTypeDef(
-    _RequiredExecuteStatementInputRequestTypeDef, _OptionalExecuteStatementInputRequestTypeDef
-):
-    pass
-
-
-ExecuteStatementOutputTypeDef = TypedDict(
-    "ExecuteStatementOutputTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "CreatedAt": datetime,
-        "Database": str,
-        "DbUser": str,
-        "Id": str,
-        "SecretArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 FieldTypeDef = TypedDict(
     "FieldTypeDef",
     {
@@ -286,28 +219,6 @@ FieldTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
-    "_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef",
-    {
-        "Id": str,
-    },
-)
-_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
-    "_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class GetStatementResultRequestGetStatementResultPaginateTypeDef(
-    _RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef,
-    _OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef,
-):
-    pass
-
-
 _RequiredGetStatementResultRequestRequestTypeDef = TypedDict(
     "_RequiredGetStatementResultRequestRequestTypeDef",
     {
@@ -330,42 +241,6 @@ class GetStatementResultRequestRequestTypeDef(
     pass
 
 
-GetStatementResultResponseTypeDef = TypedDict(
-    "GetStatementResultResponseTypeDef",
-    {
-        "ColumnMetadata": List["ColumnMetadataTypeDef"],
-        "NextToken": str,
-        "Records": List[List["FieldTypeDef"]],
-        "TotalNumRows": int,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
-    "_RequiredListDatabasesRequestListDatabasesPaginateTypeDef",
-    {
-        "Database": str,
-    },
-)
-_OptionalListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
-    "_OptionalListDatabasesRequestListDatabasesPaginateTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "DbUser": str,
-        "SecretArn": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListDatabasesRequestListDatabasesPaginateTypeDef(
-    _RequiredListDatabasesRequestListDatabasesPaginateTypeDef,
-    _OptionalListDatabasesRequestListDatabasesPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListDatabasesRequestRequestTypeDef = TypedDict(
     "_RequiredListDatabasesRequestRequestTypeDef",
     {
@@ -391,42 +266,6 @@ class ListDatabasesRequestRequestTypeDef(
     pass
 
 
-ListDatabasesResponseTypeDef = TypedDict(
-    "ListDatabasesResponseTypeDef",
-    {
-        "Databases": List[str],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
-    "_RequiredListSchemasRequestListSchemasPaginateTypeDef",
-    {
-        "Database": str,
-    },
-)
-_OptionalListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
-    "_OptionalListSchemasRequestListSchemasPaginateTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "SchemaPattern": str,
-        "SecretArn": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListSchemasRequestListSchemasPaginateTypeDef(
-    _RequiredListSchemasRequestListSchemasPaginateTypeDef,
-    _OptionalListSchemasRequestListSchemasPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListSchemasRequestRequestTypeDef = TypedDict(
     "_RequiredListSchemasRequestRequestTypeDef",
     {
@@ -454,26 +293,6 @@ class ListSchemasRequestRequestTypeDef(
     pass
 
 
-ListSchemasResponseTypeDef = TypedDict(
-    "ListSchemasResponseTypeDef",
-    {
-        "NextToken": str,
-        "Schemas": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ListStatementsRequestListStatementsPaginateTypeDef = TypedDict(
-    "ListStatementsRequestListStatementsPaginateTypeDef",
-    {
-        "RoleLevel": bool,
-        "StatementName": str,
-        "Status": StatusStringType,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListStatementsRequestRequestTypeDef = TypedDict(
     "ListStatementsRequestRequestTypeDef",
     {
@@ -486,43 +305,6 @@ ListStatementsRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListStatementsResponseTypeDef = TypedDict(
-    "ListStatementsResponseTypeDef",
-    {
-        "NextToken": str,
-        "Statements": List["StatementDataTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "_RequiredListTablesRequestListTablesPaginateTypeDef",
-    {
-        "Database": str,
-    },
-)
-_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
-    "_OptionalListTablesRequestListTablesPaginateTypeDef",
-    {
-        "ClusterIdentifier": str,
-        "ConnectedDatabase": str,
-        "DbUser": str,
-        "SchemaPattern": str,
-        "SecretArn": str,
-        "TablePattern": str,
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class ListTablesRequestListTablesPaginateTypeDef(
-    _RequiredListTablesRequestListTablesPaginateTypeDef,
-    _OptionalListTablesRequestListTablesPaginateTypeDef,
-):
-    pass
-
-
 _RequiredListTablesRequestRequestTypeDef = TypedDict(
     "_RequiredListTablesRequestRequestTypeDef",
     {
@@ -551,44 +333,105 @@ class ListTablesRequestRequestTypeDef(
     pass
 
 
-ListTablesResponseTypeDef = TypedDict(
-    "ListTablesResponseTypeDef",
+TableMemberTypeDef = TypedDict(
+    "TableMemberTypeDef",
     {
-        "NextToken": str,
-        "Tables": List["TableMemberTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "name": str,
+        "schema": str,
+        "type": str,
     },
     total=False,
 )
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+BatchExecuteStatementOutputTypeDef = TypedDict(
+    "BatchExecuteStatementOutputTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ClusterIdentifier": str,
+        "CreatedAt": datetime,
+        "Database": str,
+        "DbUser": str,
+        "Id": str,
+        "SecretArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-SqlParameterTypeDef = TypedDict(
-    "SqlParameterTypeDef",
+CancelStatementResponseTypeDef = TypedDict(
+    "CancelStatementResponseTypeDef",
     {
-        "name": str,
-        "value": str,
+        "Status": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
+ExecuteStatementOutputTypeDef = TypedDict(
+    "ExecuteStatementOutputTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "CreatedAt": datetime,
+        "Database": str,
+        "DbUser": str,
+        "Id": str,
+        "SecretArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListDatabasesResponseTypeDef = TypedDict(
+    "ListDatabasesResponseTypeDef",
+    {
+        "Databases": List[str],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListSchemasResponseTypeDef = TypedDict(
+    "ListSchemasResponseTypeDef",
+    {
+        "NextToken": str,
+        "Schemas": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeTableResponseTypeDef = TypedDict(
+    "DescribeTableResponseTypeDef",
+    {
+        "ColumnList": List[ColumnMetadataTypeDef],
+        "NextToken": str,
+        "TableName": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredExecuteStatementInputRequestTypeDef = TypedDict(
+    "_RequiredExecuteStatementInputRequestTypeDef",
+    {
+        "Database": str,
+        "Sql": str,
+    },
+)
+_OptionalExecuteStatementInputRequestTypeDef = TypedDict(
+    "_OptionalExecuteStatementInputRequestTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "Parameters": Sequence[SqlParameterTypeDef],
+        "SecretArn": str,
+        "StatementName": str,
+        "WithEvent": bool,
+    },
+    total=False,
+)
+
+
+class ExecuteStatementInputRequestTypeDef(
+    _RequiredExecuteStatementInputRequestTypeDef, _OptionalExecuteStatementInputRequestTypeDef
+):
+    pass
+
+
 _RequiredStatementDataTypeDef = TypedDict(
     "_RequiredStatementDataTypeDef",
     {
@@ -600,7 +443,7 @@ _OptionalStatementDataTypeDef = TypedDict(
     {
         "CreatedAt": datetime,
         "IsBatchStatement": bool,
-        "QueryParameters": List["SqlParameterTypeDef"],
+        "QueryParameters": List[SqlParameterTypeDef],
         "QueryString": str,
         "QueryStrings": List[str],
         "SecretArn": str,
@@ -616,40 +459,197 @@ class StatementDataTypeDef(_RequiredStatementDataTypeDef, _OptionalStatementData
     pass
 
 
-_RequiredSubStatementDataTypeDef = TypedDict(
-    "_RequiredSubStatementDataTypeDef",
+DescribeStatementResponseTypeDef = TypedDict(
+    "DescribeStatementResponseTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "CreatedAt": datetime,
+        "Database": str,
+        "DbUser": str,
+        "Duration": int,
+        "Error": str,
+        "HasResultSet": bool,
+        "Id": str,
+        "QueryParameters": List[SqlParameterTypeDef],
+        "QueryString": str,
+        "RedshiftPid": int,
+        "RedshiftQueryId": int,
+        "ResultRows": int,
+        "ResultSize": int,
+        "SecretArn": str,
+        "Status": StatusStringType,
+        "SubStatements": List[SubStatementDataTypeDef],
+        "UpdatedAt": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
+    "_RequiredDescribeTableRequestDescribeTablePaginateTypeDef",
+    {
+        "Database": str,
+    },
+)
+_OptionalDescribeTableRequestDescribeTablePaginateTypeDef = TypedDict(
+    "_OptionalDescribeTableRequestDescribeTablePaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "Schema": str,
+        "SecretArn": str,
+        "Table": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeTableRequestDescribeTablePaginateTypeDef(
+    _RequiredDescribeTableRequestDescribeTablePaginateTypeDef,
+    _OptionalDescribeTableRequestDescribeTablePaginateTypeDef,
+):
+    pass
+
+
+_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
+    "_RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef",
     {
         "Id": str,
     },
 )
-_OptionalSubStatementDataTypeDef = TypedDict(
-    "_OptionalSubStatementDataTypeDef",
+_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef = TypedDict(
+    "_OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef",
     {
-        "CreatedAt": datetime,
-        "Duration": int,
-        "Error": str,
-        "HasResultSet": bool,
-        "QueryString": str,
-        "RedshiftQueryId": int,
-        "ResultRows": int,
-        "ResultSize": int,
-        "Status": StatementStatusStringType,
-        "UpdatedAt": datetime,
+        "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
 )
 
 
-class SubStatementDataTypeDef(_RequiredSubStatementDataTypeDef, _OptionalSubStatementDataTypeDef):
+class GetStatementResultRequestGetStatementResultPaginateTypeDef(
+    _RequiredGetStatementResultRequestGetStatementResultPaginateTypeDef,
+    _OptionalGetStatementResultRequestGetStatementResultPaginateTypeDef,
+):
     pass
 
 
-TableMemberTypeDef = TypedDict(
-    "TableMemberTypeDef",
+_RequiredListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
+    "_RequiredListDatabasesRequestListDatabasesPaginateTypeDef",
     {
-        "name": str,
-        "schema": str,
-        "type": str,
+        "Database": str,
+    },
+)
+_OptionalListDatabasesRequestListDatabasesPaginateTypeDef = TypedDict(
+    "_OptionalListDatabasesRequestListDatabasesPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "DbUser": str,
+        "SecretArn": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
 )
+
+
+class ListDatabasesRequestListDatabasesPaginateTypeDef(
+    _RequiredListDatabasesRequestListDatabasesPaginateTypeDef,
+    _OptionalListDatabasesRequestListDatabasesPaginateTypeDef,
+):
+    pass
+
+
+_RequiredListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
+    "_RequiredListSchemasRequestListSchemasPaginateTypeDef",
+    {
+        "Database": str,
+    },
+)
+_OptionalListSchemasRequestListSchemasPaginateTypeDef = TypedDict(
+    "_OptionalListSchemasRequestListSchemasPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListSchemasRequestListSchemasPaginateTypeDef(
+    _RequiredListSchemasRequestListSchemasPaginateTypeDef,
+    _OptionalListSchemasRequestListSchemasPaginateTypeDef,
+):
+    pass
+
+
+ListStatementsRequestListStatementsPaginateTypeDef = TypedDict(
+    "ListStatementsRequestListStatementsPaginateTypeDef",
+    {
+        "RoleLevel": bool,
+        "StatementName": str,
+        "Status": StatusStringType,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_RequiredListTablesRequestListTablesPaginateTypeDef",
+    {
+        "Database": str,
+    },
+)
+_OptionalListTablesRequestListTablesPaginateTypeDef = TypedDict(
+    "_OptionalListTablesRequestListTablesPaginateTypeDef",
+    {
+        "ClusterIdentifier": str,
+        "ConnectedDatabase": str,
+        "DbUser": str,
+        "SchemaPattern": str,
+        "SecretArn": str,
+        "TablePattern": str,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class ListTablesRequestListTablesPaginateTypeDef(
+    _RequiredListTablesRequestListTablesPaginateTypeDef,
+    _OptionalListTablesRequestListTablesPaginateTypeDef,
+):
+    pass
+
+
+GetStatementResultResponseTypeDef = TypedDict(
+    "GetStatementResultResponseTypeDef",
+    {
+        "ColumnMetadata": List[ColumnMetadataTypeDef],
+        "NextToken": str,
+        "Records": List[List[FieldTypeDef]],
+        "TotalNumRows": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListTablesResponseTypeDef = TypedDict(
+    "ListTablesResponseTypeDef",
+    {
+        "NextToken": str,
+        "Tables": List[TableMemberTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListStatementsResponseTypeDef = TypedDict(
+    "ListStatementsResponseTypeDef",
+    {
+        "NextToken": str,
+        "Statements": List[StatementDataTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
